import { BrowserModule } from '@angular/platform-browser';
import { BrowserAnimationsModule } from "@angular/platform-browser/animations";
import { NgModule } from '@angular/core';

import { HttpClientModule } from '@angular/common/http';

import {
    Routes,
    RouterModule
} from '@angular/router';

import {
    MatInputModule,
    MatPaginatorModule,
    MatProgressSpinnerModule,
    MatSortModule,
    MatToolbarModule,
    MatTableModule
} from '@angular/material';

import { MatButtonModule } from '@angular/material/button';

import { FlexLayoutModule } from "@angular/flex-layout";

import { AppComponent } from './app.component';
import { VideosComponent } from './videos/videos.component';
import { CommentsComponent } from './comments/comments.component';
import { SplitBadgesPipe } from './pipes/splitbadges.pipe';
import { SplitMessagePipe } from './pipes/splitmessage.pipe';
import { ToHMSPipe } from './pipes/tohms.pipe';
import { CommentsService } from './services/comments.service';
import { ImagesService } from './services/images.service';


const routes: Routes = [
    { path: '', component: VideosComponent },
    { path: 'videos/:id', component: CommentsComponent },
    { path: '**', redirectTo: '/' }
];

@NgModule({
    declarations: [
        AppComponent,
        VideosComponent,
        CommentsComponent,
        SplitBadgesPipe,
        SplitMessagePipe,
        ToHMSPipe
    ],
    imports: [
        BrowserModule,
        BrowserAnimationsModule,
        HttpClientModule,
        FlexLayoutModule,
        MatButtonModule,
        MatInputModule,
        MatPaginatorModule,
        MatProgressSpinnerModule,
        MatSortModule,
        MatToolbarModule,
        MatTableModule,
        RouterModule.forRoot(routes)
    ],
    providers: [
        CommentsService,
        ImagesService
    ],
    bootstrap: [ AppComponent ]
})
export class AppModule { }
